#
# spec file for package opusfile
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2013 Bjørn Lie (zaitor@opensuse.org).
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 0
Name:           opusfile
Version:        0.12
Release:        2.4
Summary:        A high-level API for decoding and seeking within .opus files
License:        BSD-3-Clause
Group:          System/Libraries
URL:            https://www.opus-codec.org/
Source:         https://downloads.xiph.org/releases/opus/opusfile-%{version}.tar.gz
# PATCH-FIX-UPSTREAM opusfile-CVE-2022-47021.patch boo#1207381 mgorse@suse.com -- fix a NULL pointer dereference.
Patch0:         opusfile-CVE-2022-47021.patch
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ogg) >= 1.3
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(opus)

%description
opusfile provides a high-level API for decoding and seeking within .opus files.
It includes:
* Support for all files with at least one Opus stream
  (including multichannel files or Ogg files where Opus is muxed with something else).
* Full support, including seeking, for chained files.
* A simple stereo downmixing API
  (allowing chained files to be decoded with a single output format, even if the channel count changes).
* Support for reading from a file, memory buffer, or over HTTP(S) (including seeking).
* Support for both random access and streaming data sources.

%package -n libopusfile%{soname}
Summary:        A high-level API for decoding and seeking within .opus files
Group:          System/Libraries

%description -n libopusfile%{soname}
opusfile provides a high-level API for decoding and seeking within .opus files.
It includes:
* Support for all files with at least one Opus stream
  (including multichannel files or Ogg files where Opus is muxed with something else).
* Full support, including seeking, for chained files.
* A simple stereo downmixing API
  (allowing chained files to be decoded with a single output format, even if the channel count changes).
* Support for reading from a file, memory buffer, or over HTTP(S) (including seeking).
* Support for both random access and streaming data sources.

%package devel
Summary:        Development package for %{name}
Group:          Development/Libraries/Other
Requires:       libopusfile%{soname} = %{version}
Requires:       pkgconfig

%description devel
Files for development with %{name}.

%prep
%autosetup -p1

%build
%configure \
  --disable-static \
  --disable-silent-rules
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libopusfile%{soname} -p /sbin/ldconfig
%postun -n libopusfile%{soname} -p /sbin/ldconfig

%files -n libopusfile%{soname}
%license COPYING
%doc AUTHORS
%{_libdir}/libopusfile.so.%{soname}
%{_libdir}/libopusfile.so.%{soname}.*
%{_libdir}/libopusurl.so.%{soname}
%{_libdir}/libopusurl.so.%{soname}.*

%files devel
%doc %{_datadir}/doc/opusfile/
%{_includedir}/opus/opusfile.h
%{_libdir}/pkgconfig/opusfile.pc
%{_libdir}/pkgconfig/opusurl.pc
%{_libdir}/libopusfile.so
%{_libdir}/libopusurl.so

%changelog
* Wed Mar 15 2023 Michael Gorse <mgorse@suse.com>
- Add opusfile-CVE-2022-47021.patch: fix a NULL pointer
  dereference (boo#1207381 CVE-2022-47021).
* Fri Sep 11 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.12:
  * Fix stack overflow buffering out-of-sequence streams.
  * Fix possible divide-by-zero.
  * Fix issues with seeking in the win32 backend.
  * Fix an issue where the seek algorithm could be confused by stream data changing between reads.
  * Clean up compiler and scan-build warnings.
  * Avoid use of the deprecated ftime() function which has Y2038 problems.
  * Remove undefined behaviour memcpy(NULL) in op_read_native().
  * Visual Studio project files updated for libogg 1.3.4 library name change.
  * Various build systems updates.
  * Various integration and testing environment improvements.
* Thu Sep 20 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 0.11:
  * Fix two potential integer overflows. (These were not security-critical unless the compiler took the opportunity provided by the undefined behavior to format your hard drive.)
  * Allow JPEGs in METADATA_BLOCK_PICTURE tags to include EXIF data.
  * A few warning fixes for gcc 8.
  * Make opus_tags_copy return OP_EFAULT on failure instead of returning success.
  * Various integration and testing environment improvements.
* Mon Dec 18 2017 avindra@opensuse.org
- Update to version 0.10:
  + Fix an out-of-bounds read matching serial numbers.
- cleanup with spec-cleaner
- add "--disable-silent-rules" to ./configure
* Tue Aug  8 2017 zaitor@opensuse.org
- Update to version 0.9:
  + Fix an invalid free with tag handling.
  + Improve handling of corrupt streams.
  + Improve performance on streams with many chain segments.
  + Improve TLS host validation.
  + Align op_raw_total to work better with op_raw_seek.
  + Documentation and build improvements.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 0.8:
  + Add support for OpenSSL 1.1.x.
  + Fix issues with tag parsing introduced in v0.7.
  + Fix skip logic for multiplexed non-Opus data.
* Fri Jan  8 2016 ecsos@opensuse.org
- Update to version 0.7
  + Add API to access and preserve binary metadata.
  + Add support for R128_ALBUM_GAIN metadata tag.
  + Better seeking with continued packets and multiplexed streams.
  + Portability and build fixes.
* Thu Dec 18 2014 zaitor@opensuse.org
- Update to version 0.6:
  + Fix bugs with comment handling.
  + Fix build for BSD.
  + Fix bugs handling invalid and non-opus streams.
* Thu Feb 13 2014 reddwarf@opensuse.org
- Update to 0.5
  * Report HTTP (ICY) headers to client
  * New tag comparison and copy functions
  * New application decoding callback API for advanced clients
  * New dither disable function for advanced clients
  * constify API
  * Avoid clipping downmixing from a fixed-point decoder
  * Better practices for dual stack IPv6
  * Documentation improvements
  * Fix a unicode bug on Windows
  * Fix proxy user/password macros
  * Fix HTTP pipelining support detection
* Sat Sep 14 2013 zaitor@opensuse.org
- Initial packaging for openSUSE.
